@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "textconvertertest.h"
@@ -324,6 +311,10 @@ void TextConverterTest::shouldConvertTextWithEmoji_data()
     QTest::newRow("inline-code-with-smiley") << QStringLiteral(":) `:)` :)")
                                              << QStringLiteral("<div>%1 <code style='background-color:$BGCOLOR$'>:)</code> %1</div>").arg(smileyText)
                                              << QStringLiteral("www.kde.org");
+
+    QTest::newRow("url-with-emoji") << QStringLiteral("https://www.kde.org/:x:/bla.html")
+                                    << QStringLiteral("<div>%1 <code style='background-color:$BGCOLOR$'>:)</code> %1</div>").arg(smileyText)
+                                    << QStringLiteral("www.kde.org");
 }
 
 void TextConverterTest::shouldConvertTextWithEmoji()
@@ -348,5 +339,6 @@ void TextConverterTest::shouldConvertTextWithEmoji()
         // the text color is syntax highlighting theme dependent, so hard for us to check
         actualOutput.replace(QRegularExpression(QStringLiteral("<code><span style=\".+\">:\\)</span></code>")), QStringLiteral("<code>:)</code>"));
     }
+    QEXPECT_FAIL("url-with-emoji", "Currently it if we have a emoji char in url", Continue);
     QCOMPARE(actualOutput, output); // TODO add autotest for highlightwords
 }
