@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "adminroomsmodel.h"
@@ -26,9 +12,7 @@ AdminRoomsModel::AdminRoomsModel(QObject *parent)
 {
 }
 
-AdminRoomsModel::~AdminRoomsModel()
-{
-}
+AdminRoomsModel::~AdminRoomsModel() = default;
 
 int AdminRoomsModel::rowCount(const QModelIndex &parent) const
 {
@@ -57,12 +41,13 @@ QVariant AdminRoomsModel::headerData(int section, Qt::Orientation orientation, i
         case AdminRoomsRoles::DefaultRoom:
             return i18n("Default Room");
         case AdminRoomsRoles::ChannelType:
-            return i18n("Type");
         case AdminRoomsRoles::ChannelTypeStr:
             return i18n("Type");
+        case AdminRoomsRoles::Featured:
+            return {};
         }
     }
-    return QVariant();
+    return {};
 }
 
 int AdminRoomsModel::columnCount(const QModelIndex &parent) const
@@ -101,6 +86,8 @@ QVariant AdminRoomsModel::data(const QModelIndex &index, int role) const
         return adminroom.channelType();
     case AdminRoomsRoles::ChannelTypeStr:
         return adminroom.channelTypeStr();
+    case AdminRoomsRoles::Featured:
+        return adminroom.featured();
     }
 
     return {};
@@ -162,7 +149,7 @@ void AdminRoomsModel::addMoreElements(const QJsonObject &obj)
 
 QList<int> AdminRoomsModel::hideColumns() const
 {
-    return {AdminRoomsRoles::Identifier, AdminRoomsRoles::ChannelType};
+    return {AdminRoomsRoles::Identifier, AdminRoomsRoles::ChannelType, AdminRoomsRoles::Featured};
 }
 
 void AdminRoomsModel::removeElement(const QString &identifier)
