@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "discussionsfilterproxymodel.h"
@@ -33,9 +20,7 @@ DiscussionsFilterProxyModel::DiscussionsFilterProxyModel(DiscussionsModel *model
     connect(mDiscussionsModel, &DiscussionsModel::loadingInProgressChanged, this, &DiscussionsFilterProxyModel::loadingInProgressChanged);
 }
 
-DiscussionsFilterProxyModel::~DiscussionsFilterProxyModel()
-{
-}
+DiscussionsFilterProxyModel::~DiscussionsFilterProxyModel() = default;
 
 void DiscussionsFilterProxyModel::setFilterString(const QString &string)
 {
