@@ -1,22 +1,8 @@
 /*
 
- * Copyright 2016  Riccardo Iaconelli <riccardo@kde.org>
+ * SPDX-FileCopyrightText: 2016 Riccardo Iaconelli <riccardo@kde.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
  */
 
@@ -130,7 +116,7 @@ int RoomModel::rowCount(const QModelIndex &parent) const
 QVariant RoomModel::data(const QModelIndex &index, int role) const
 {
     if (index.row() < 0 || index.row() >= mRoomsList.count()) {
-        return QVariant();
+        return {};
     }
 
     Room *r = mRoomsList.at(index.row());
