@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "rocketchataccount.h"
@@ -95,7 +81,7 @@
 #include "groups/groupopenjob.h"
 #include "users/setstatusjob.h"
 #include "users/usersautocompletejob.h"
-
+#include "away/awaymanager.h"
 #define USE_REASTAPI_JOB 1
 
 RocketChatAccount::RocketChatAccount(const QString &accountFileName, QObject *parent)
@@ -105,6 +91,7 @@ RocketChatAccount::RocketChatAccount(const QString &accountFileName, QObject *pa
     , mMessageCache(new MessageCache(this, this))
     , mManageChannels(new ManageChannels(this))
     , mCustomSoundManager(new CustomSoundsManager(this))
+    , mAwayManager(new AwayManager(this, this))
 {
     qCDebug(RUQOLA_LOG) << " RocketChatAccount::RocketChatAccount(const QString &accountFileName, QObject *parent)" << accountFileName;
     // create an unique file for each account
@@ -241,6 +228,7 @@ RocketChatAccount::RocketChatAccount(const QString &accountFileName, QObject *pa
     connect(mCustomSoundManager, &CustomSoundsManager::customSoundRemoved, this, &RocketChatAccount::customSoundRemoved);
     connect(mCustomSoundManager, &CustomSoundsManager::customSoundAdded, this, &RocketChatAccount::customSoundAdded);
     connect(mCustomSoundManager, &CustomSoundsManager::customSoundUpdated, this, &RocketChatAccount::customSoundUpdated);
+    connect(mAwayManager, &AwayManager::awayChanged, this, &RocketChatAccount::slotAwayStatusChanged);
 }
 
 RocketChatAccount::~RocketChatAccount()
@@ -686,7 +674,7 @@ void RocketChatAccount::joinJitsiConfCall(const QString &roomId)
     qCDebug(RUQOLA_LOG) << " void RocketChatAccount::joinJitsiConfCall(const QString &roomId)" << roomId;
     // const QString hash = QString::fromLatin1(QCryptographicHash::hash((mRuqolaServerConfig->uniqueId() + roomId).toUtf8(), QCryptographicHash::Md5).toHex());
     const QString hash = mRuqolaServerConfig->uniqueId() + roomId;
-#if defined(Q_OS_IOS) || defined(Q_OS_ANDROID)
+#if defined(Q_OS_IOS)
     const QString scheme = QStringLiteral("org.jitsi.meet://");
 #else
     const QString scheme = QStringLiteral("https://");
@@ -794,11 +782,6 @@ void RocketChatAccount::setDefaultStatus(User::PresenceStatus status, const QStr
     restApi()->setUserStatus(userId(), type, messageStatus);
 }
 
-void RocketChatAccount::changeDefaultStatus(int index, const QString &messageStatus)
-{
-    setDefaultStatus(mStatusModel->status(index), messageStatus);
-}
-
 void RocketChatAccount::loadEmoji(const QJsonObject &obj)
 {
     mEmojiManager->loadCustomEmoji(obj);
@@ -1468,6 +1451,12 @@ void RocketChatAccount::deleteEmojiCustom(const QJsonArray &replyArray)
     mEmojiManager->deleteEmojiCustom(replyArray);
 }
 
+void RocketChatAccount::privateSettingsUpdated(const QJsonArray &replyArray)
+{
+    // TODO
+    qWarning() << " privateSettingsUpdated not implemented " << replyArray;
+}
+
 void RocketChatAccount::permissionUpdated(const QJsonArray &replyArray)
 {
     if (mPermissionManager.updatePermission(replyArray)) {
@@ -1632,9 +1621,14 @@ void RocketChatAccount::downloadFile(const QString &downloadFileUrl, const QUrl
     mCache->downloadFile(downloadFileUrl, localFile);
 }
 
-QUrl RocketChatAccount::attachmentUrl(const QString &url)
+QUrl RocketChatAccount::attachmentUrlFromLocalCache(const QString &url)
 {
-    return mCache->attachmentUrl(url);
+    return mCache->attachmentUrlFromLocalCache(url);
+}
+
+bool RocketChatAccount::attachmentIsInLocalCache(const QString &url)
+{
+    return mCache->attachmentIsInLocalCache(url);
 }
 
 QString RocketChatAccount::loadMessagesHistory(const QString &roomID, qint64 numberOfMessages)
@@ -2290,6 +2284,8 @@ void RocketChatAccount::initializeAccount()
     if (RuqolaGlobalConfig::self()->setOnlineAccounts()) {
         ddp()->setDefaultStatus(User::PresenceStatus::PresenceOnline);
     }
+    // Initialize sounds
+    mCustomSoundManager->initializeDefaultSounds();
     ddp()->listCustomSounds();
     customUsersStatus();
     slotLoadRoles();
@@ -2429,8 +2425,8 @@ RuqolaServerConfig::ServerConfigFeatureTypes RocketChatAccount::serverConfigFeat
 
 void RocketChatAccount::parseOwnInfoDone(const QJsonObject &replyObject)
 {
-    // qDebug() << "RocketChatBackend::parseOwnInfoDown " << replyObject;
     mOwnUser.parseOwnUserInfo(replyObject);
+    mAwayManager->updateSettings();
     const User user = mOwnUser.user();
     // qDebug() << " USER  " << user;
     if (user.isValid()) {
@@ -2628,6 +2624,7 @@ void RocketChatAccount::setUserPreferences(const RocketChatRestApi::UsersSetPref
 
 void RocketChatAccount::slotUsersSetPreferencesDone(const QJsonObject &replyObject)
 {
+    qDebug() << " void RocketChatAccount::slotUsersSetPreferencesDone(const QJsonObject &replyObject)" << replyObject;
     const QJsonObject user = replyObject.value(QLatin1String("user")).toObject();
     if (user.value(QLatin1String("_id")).toString() == userId()) {
         OwnUserPreferences ownUserPreferences;
@@ -2683,3 +2680,13 @@ CustomSoundsManager *RocketChatAccount::customSoundManager() const
 {
     return mCustomSoundManager;
 }
+
+void RocketChatAccount::slotAwayStatusChanged(bool away)
+{
+    if (away) {
+        restApi()->setUserStatus(userId(), RocketChatRestApi::SetStatusJob::Away, {});
+    } else {
+        restApi()->setUserStatus(userId(), RocketChatRestApi::SetStatusJob::OnLine, {});
+    }
+    qCDebug(RUQOLA_LOG) << "RocketChatAccount::slotAwayStatusChanged  " << away;
+}
