@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
@@ -94,6 +80,7 @@ class MessageCache;
 class ManageChannels;
 class EmoticonCustomModel;
 class CustomSoundsManager;
+class AwayManager;
 
 namespace RocketChatRestApi
 {
@@ -173,7 +160,6 @@ public:
     void joinRoom(const QString &roomId, const QString &joinCode = QString());
     void openDirectChannel(const QString &username);
     void setDefaultStatus(User::PresenceStatus status, const QString &messageStatus); // Move to private no ?
-    void changeDefaultStatus(int index, const QString &messageStatus);
     void createJitsiConfCall(const QString &roomId);
     void deleteMessage(const QString &messageId, const QString &roomId);
     void userAutocomplete(const QString &searchText, const QString &exception);
@@ -185,7 +171,7 @@ public:
     void
     uploadFile(const QString &roomId, const QString &description, const QString &messageText, const QUrl &fileUrl, const QString &threadMessageId = QString());
     Q_REQUIRED_RESULT QString avatarUrl(const Utils::AvatarInfo &info);
-    Q_REQUIRED_RESULT QUrl attachmentUrl(const QString &url);
+    Q_REQUIRED_RESULT QUrl attachmentUrlFromLocalCache(const QString &url);
     void loadHistory(const QString &roomID, bool initial = false, qint64 timeStep = 0);
     void channelAndPrivateAutocomplete(const QString &pattern);
 
@@ -479,6 +465,8 @@ public:
 
     Q_REQUIRED_RESULT CustomSoundsManager *customSoundManager() const;
 
+    Q_REQUIRED_RESULT bool attachmentIsInLocalCache(const QString &url);
+    void privateSettingsUpdated(const QJsonArray &replyArray);
 Q_SIGNALS:
     void avatarWasChanged(const Utils::AvatarInfo &info);
     void accountInitialized();
@@ -584,6 +572,7 @@ private:
     void slotDirectoryDone(const QJsonObject &obj);
     void updateCustomEmojiList();
     void slotLoadRoles();
+    void slotAwayStatusChanged(bool away);
 
     AccountRoomSettings *const mAccountRoomSettings;
 
@@ -640,6 +629,7 @@ private:
     MessageCache *const mMessageCache;
     ManageChannels *const mManageChannels;
     CustomSoundsManager *const mCustomSoundManager;
+    AwayManager *const mAwayManager;
     OwnUser mOwnUser;
     CustomUserStatuses mCustomUserStatuses;
     PermissionManager mPermissionManager;
