@@ -1,23 +1,9 @@
 /*
 
- * Copyright 2016  Riccardo Iaconelli <riccardo@kde.org>
- * Copyright 2018-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2016 Riccardo Iaconelli <riccardo@kde.org>
+ * SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
  */
 
@@ -139,9 +125,7 @@ RocketChatBackend::RocketChatBackend(RocketChatAccount *account, QObject *parent
     connect(mRocketChatAccount, &RocketChatAccount::connectedChanged, this, &RocketChatBackend::slotConnectedChanged);
 }
 
-RocketChatBackend::~RocketChatBackend()
-{
-}
+RocketChatBackend::~RocketChatBackend() = default;
 
 // TODO load public info even if we are not connected.
 void RocketChatBackend::slotConnectedChanged()
@@ -156,6 +140,7 @@ void RocketChatBackend::slotConnectedChanged()
     restApi->serverInfo(false);
     connect(restApi, &RocketChatRestApi::Connection::serverInfoDone, this, &RocketChatBackend::parseServerVersionDone, Qt::UniqueConnection);
     connect(restApi, &RocketChatRestApi::Connection::serverInfoFailed, this, &RocketChatBackend::slotGetServerInfoFailed, Qt::UniqueConnection);
+    connect(restApi, &RocketChatRestApi::Connection::privateInfoDone, this, &RocketChatBackend::slotPrivateInfoDone, Qt::UniqueConnection);
 
     ddp->method(QStringLiteral("public-settings/get"), QJsonDocument(), process_publicsettings);
 }
@@ -193,6 +178,7 @@ void RocketChatBackend::processIncomingMessages(const QJsonArray &messages, bool
         if (messageModel) {
             if (!m.threadMessageId().isEmpty()) {
                 mRocketChatAccount->updateThreadMessageList(m);
+                qDebug() << " Update thread message";
             }
             if (room) {
                 mMessageLogger->addMessage(mRocketChatAccount->accountName(), room->displayFName(), m);
@@ -237,6 +223,11 @@ void RocketChatBackend::slotLoginStatusChanged()
     }
 }
 
+void RocketChatBackend::slotPrivateInfoDone(const QJsonObject &data)
+{
+    qDebug() << "parse private info not implemented . Needed ? "; // << data;
+}
+
 void RocketChatBackend::parseServerVersionDone(const QString &version)
 {
     // qCDebug(RUQOLA_LOG) << " void RocketChatBackend::parseServerVersionDone(const QString &version)******************" << version;
@@ -553,6 +544,8 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
             mRocketChatAccount->deleteEmojiCustom(contents);
         } else if (eventname == QLatin1String("permissions-changed")) {
             mRocketChatAccount->permissionUpdated(contents);
+        } else if (eventname == QLatin1String("private-settings-changed")) {
+            mRocketChatAccount->privateSettingsUpdated(contents);
         } else {
             qWarning() << "stream-notify-logged not supported " << fields;
         }
@@ -570,7 +563,7 @@ void RocketChatBackend::slotChanged(const QJsonObject &object)
         //{"collection":"stream-notify-all","fields":{"args":[{"soundData":{"_id":"LmShBQiqaCJDbgduR","_updatedAt":{"$date":1603350386481},"extension":"mp3","name":"ss"}}],"eventName":"deleteCustomSound"},"id":"id","msg":"changed"}
     } else if (collection == QLatin1String("stream-stdout")) {
         const QJsonObject fields = object.value(QLatin1String("fields")).toObject();
-        const QString eventname = fields.value(QLatin1String("eventName")).toString();
+        // const QString eventname = fields.value(QLatin1String("eventName")).toString();
         const QJsonArray contents = fields.value(QLatin1String("args")).toArray();
         mRocketChatAccount->addStdoutInfo(contents);
     } else if (collection == QLatin1String("stream-roles")) {
