@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "administratorcustomemojiwidget.h"
@@ -53,9 +39,7 @@ AdministratorCustomEmojiWidget::AdministratorCustomEmojiWidget(RocketChatAccount
     connect(mTreeView, &QTreeView::doubleClicked, this, &AdministratorCustomEmojiWidget::slotModifyCustomEmoji);
 }
 
-AdministratorCustomEmojiWidget::~AdministratorCustomEmojiWidget()
-{
-}
+AdministratorCustomEmojiWidget::~AdministratorCustomEmojiWidget() = default;
 
 void AdministratorCustomEmojiWidget::updateLabel()
 {
@@ -117,7 +101,6 @@ void AdministratorCustomEmojiWidget::slotAddCustomEmoji()
         mRocketChatAccount->restApi()->initializeRestApiJob(job);
         connect(job, &RocketChatRestApi::EmojiCustomCreateJob::emojiCustomCreateDone, this, [](const QJsonObject &replyObject) {
             qDebug() << " replyObject " << replyObject;
-            // TODO
             // TODO update list
         });
         if (!job->start()) {
@@ -149,7 +132,6 @@ void AdministratorCustomEmojiWidget::slotModifyCustomEmoji(const QModelIndex &in
         mRocketChatAccount->restApi()->initializeRestApiJob(job);
         connect(job, &RocketChatRestApi::EmojiCustomUpdateJob::emojiCustomUpdateDone, this, [](const QJsonObject &replyObject) {
             qDebug() << " replyObject " << replyObject;
-            // TODO
             // TODO update list
         });
         if (!job->start()) {
@@ -161,7 +143,12 @@ void AdministratorCustomEmojiWidget::slotModifyCustomEmoji(const QModelIndex &in
 
 void AdministratorCustomEmojiWidget::slotRemoveCustomEmoji(const QModelIndex &index)
 {
-    if (KMessageBox::questionYesNo(this, i18n("Do you want to remove this emoji?"), i18nc("@title", "Remove Emoji")) == KMessageBox::Yes) {
+    if (KMessageBox::questionYesNo(this,
+                                   i18n("Do you want to remove this emoji?"),
+                                   i18nc("@title", "Remove Emoji"),
+                                   KStandardGuiItem::remove(),
+                                   KStandardGuiItem::cancel())
+        == KMessageBox::Yes) {
         auto job = new RocketChatRestApi::EmojiCustomDeleteJob(this);
         const QString emojiId = index.data().toString();
         job->setEmojiId(emojiId);
