@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "customuserstatustreewidget.h"
@@ -34,9 +20,7 @@ CustomUserStatusTreeWidgetItem::CustomUserStatusTreeWidgetItem(QTreeWidget *pare
 {
 }
 
-CustomUserStatusTreeWidgetItem::~CustomUserStatusTreeWidgetItem()
-{
-}
+CustomUserStatusTreeWidgetItem::~CustomUserStatusTreeWidgetItem() = default;
 
 CustomUserStatus CustomUserStatusTreeWidgetItem::userStatus() const
 {
@@ -65,9 +49,7 @@ CustomUserStatusTreeWidget::CustomUserStatusTreeWidget(RocketChatAccount *accoun
     connect(this, &CustomUserStatusTreeWidget::itemDoubleClicked, this, &CustomUserStatusTreeWidget::editClicked);
 }
 
-CustomUserStatusTreeWidget::~CustomUserStatusTreeWidget()
-{
-}
+CustomUserStatusTreeWidget::~CustomUserStatusTreeWidget() = default;
 
 void CustomUserStatusTreeWidget::initialize()
 {
@@ -131,7 +113,11 @@ void CustomUserStatusTreeWidget::removeClicked()
     auto customUserStatusItem = static_cast<CustomUserStatusTreeWidgetItem *>(currentItem());
     const CustomUserStatus userStatus = customUserStatusItem->userStatus();
     if (KMessageBox::Yes
-        == KMessageBox::questionYesNo(this, i18n("Do you want to remove \"%1\"?", userStatus.name()), i18nc("@title", "Remove Custom User Status"))) {
+        == KMessageBox::questionYesNo(this,
+                                      i18n("Do you want to remove \"%1\"?", userStatus.name()),
+                                      i18nc("@title", "Remove Custom User Status"),
+                                      KStandardGuiItem::remove(),
+                                      KStandardGuiItem::cancel())) {
         mRocketChatAccount->removeCustomUserStatus(userStatus.identifier());
     }
 }
