@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "permissionswidget.h"
@@ -49,7 +35,6 @@ PermissionsWidget::PermissionsWidget(RocketChatAccount *account, QWidget *parent
 
     auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
-    mainLayout->setContentsMargins({});
 
     mSearchLineWidget->setObjectName(QStringLiteral("mSearchLineWidget"));
     mSearchLineWidget->setPlaceholderText(i18n("Search Permissions..."));
@@ -66,9 +51,7 @@ PermissionsWidget::PermissionsWidget(RocketChatAccount *account, QWidget *parent
     connect(mTreeView, &QTreeView::doubleClicked, this, &PermissionsWidget::slotModifyDoubleClickRoles);
 }
 
-PermissionsWidget::~PermissionsWidget()
-{
-}
+PermissionsWidget::~PermissionsWidget() = default;
 
 void PermissionsWidget::slotFilterTextChanged(const QString &str)
 {
@@ -132,8 +115,8 @@ void PermissionsWidget::modifyRoles(const QModelIndex &index)
 void PermissionsWidget::slotEditRoles(const QStringList &roles, const QString &identifier)
 {
     QPointer<PermissionsEditDialog> dialog = new PermissionsEditDialog(this, identifier);
-    dialog->setRoles(roles);
     dialog->setRolesInfo(mRoleInfo);
+    dialog->setRoles(roles);
     if (dialog->exec()) {
         const QStringList lst = dialog->roles();
         auto permissionsUpdateJob = new RocketChatRestApi::PermissionUpdateJob(this);
