@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2020 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2020 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "completionlistview.h"
@@ -37,9 +23,7 @@ CompletionListView::CompletionListView()
     connect(this, &QListView::clicked, this, &CompletionListView::complete);
 }
 
-CompletionListView::~CompletionListView()
-{
-}
+CompletionListView::~CompletionListView() = default;
 
 void CompletionListView::setTextWidget(QWidget *textWidget)
 {
