@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "directchannelinfowidget.h"
@@ -31,7 +17,7 @@
 #include <QIcon>
 #include <QLabel>
 
-DirectChannelInfoWidget::DirectChannelInfoWidget(QWidget *parent)
+DirectChannelInfoWidget::DirectChannelInfoWidget(RocketChatAccount *account, QWidget *parent)
     : QWidget(parent)
     , mName(new QLabel(this))
     , mUserName(new QLabel(this))
@@ -44,6 +30,7 @@ DirectChannelInfoWidget::DirectChannelInfoWidget(QWidget *parent)
     , mLastLogin(new QLabel(this))
     , mEmailsInfo(new QLabel(this))
     , mMainLayout(new QFormLayout(this))
+    , mRocketChatAccount(account)
 {
     mMainLayout->setObjectName(QStringLiteral("mainLayout"));
     mMainLayout->setContentsMargins({});
@@ -88,20 +75,22 @@ DirectChannelInfoWidget::DirectChannelInfoWidget(QWidget *parent)
     mMainLayout->addRow(i18n("Email:"), mEmailsInfo);
 }
 
-DirectChannelInfoWidget::~DirectChannelInfoWidget()
-{
-}
+DirectChannelInfoWidget::~DirectChannelInfoWidget() = default;
 
 void DirectChannelInfoWidget::setUserName(const QString &userName)
 {
     fetchUserInfo(userName);
 }
 
+void DirectChannelInfoWidget::setRoles(const QVector<RoleInfo> &newRoles)
+{
+    mListRoleInfos = newRoles;
+}
+
 void DirectChannelInfoWidget::fetchUserInfo(const QString &userName)
 {
-    auto *rcAccount = Ruqola::self()->rocketChatAccount();
     auto userJob = new RocketChatRestApi::UserInfoJob(this);
-    rcAccount->restApi()->initializeRestApiJob(userJob);
+    mRocketChatAccount->restApi()->initializeRestApiJob(userJob);
     RocketChatRestApi::UserInfoJob::UserInfo info;
     info.userIdentifier = userName;
     info.userInfoType = RocketChatRestApi::UserInfoJob::UserInfoType::UserName;
@@ -126,7 +115,6 @@ void DirectChannelInfoWidget::slotUserInfoDone(const QJsonObject &obj)
 
 void DirectChannelInfoWidget::setUser(const User &user)
 {
-    auto *rcAccount = Ruqola::self()->rocketChatAccount();
     const QString name = user.name();
     if (name.isEmpty()) {
         hideWidget(mName);
@@ -145,14 +133,23 @@ void DirectChannelInfoWidget::setUser(const User &user)
     Utils::AvatarInfo info;
     info.avatarType = Utils::AvatarType::User;
     info.identifier = user.userName();
-    const QUrl iconUrlStr = QUrl(rcAccount->avatarUrl(info));
+    const QUrl iconUrlStr = QUrl(mRocketChatAccount->avatarUrl(info));
     mAvatar->setPixmap(QIcon(iconUrlStr.toLocalFile()).pixmap(60, 60)); // TODO hardcoded ?
 
-    const QStringList i18nRoles{user.i18nRoles()};
-    if (i18nRoles.isEmpty()) {
+    const QStringList roles{user.roles()};
+    if (roles.isEmpty()) {
         hideWidget(mRoles);
     } else {
-        mRoles->setText(i18nRoles.join(QStringLiteral(", ")));
+        QStringList newRolesList;
+        for (const QString &rolestr : roles) {
+            for (const RoleInfo &roleInfo : std::as_const(mListRoleInfos)) {
+                if (roleInfo.identifier() == rolestr) {
+                    newRolesList.append(User::roleI18n(roleInfo.name()));
+                    break;
+                }
+            }
+        }
+        mRoles->setText(newRolesList.join(QStringLiteral(", ")));
     }
 
     if (user.createdAt().isValid()) {
@@ -168,8 +165,8 @@ void DirectChannelInfoWidget::setUser(const User &user)
     }
 
     if (user.userEmailsInfo().isValid()) {
-        const QString info = i18n("%1 [%2]", user.userEmailsInfo().email, user.userEmailsInfo().verified ? i18n("Verified") : i18n("Not verified"));
-        mEmailsInfo->setText(info);
+        const QString infoStr = i18n("%1 [%2]", user.userEmailsInfo().email, user.userEmailsInfo().verified ? i18n("Verified") : i18n("Not verified"));
+        mEmailsInfo->setText(infoStr);
     } else {
         hideWidget(mEmailsInfo);
     }
