@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "showimagedialog.h"
@@ -23,7 +9,9 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
+#include <KStandardAction>
 #include <QDialogButtonBox>
+#include <QMenu>
 #include <QPushButton>
 #include <QVBoxLayout>
 
@@ -31,9 +19,10 @@ namespace
 {
 static const char myShowImageDialogGroupName[] = "ShowImageDialog";
 }
-ShowImageDialog::ShowImageDialog(QWidget *parent)
+ShowImageDialog::ShowImageDialog(RocketChatAccount *account, QWidget *parent)
     : QDialog(parent)
-    , mShowImageWidget(new ShowImageWidget(this))
+    , mShowImageWidget(new ShowImageWidget(account, this))
+    , mClipboardMenu(new QMenu(this))
 {
     setWindowTitle(i18nc("@title:window", "Display Image"));
     auto mainLayout = new QVBoxLayout(this);
@@ -44,6 +33,28 @@ ShowImageDialog::ShowImageDialog(QWidget *parent)
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close | QDialogButtonBox::Save, this);
     buttonBox->setObjectName(QStringLiteral("button"));
+
+    mClipboardImageAction = KStandardAction::copy(mShowImageWidget, &ShowImageWidget::copyImage, this);
+    mClipboardImageAction->setObjectName(QStringLiteral("clipboardLocationAction"));
+    mClipboardImageAction->setText(i18n("Copy Image to Clipboard"));
+
+    auto clipboardLocationAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy Location to Clipboard"), this);
+    clipboardLocationAction->setObjectName(QStringLiteral("clipboardLocationAction"));
+    connect(clipboardLocationAction, &QAction::triggered, mShowImageWidget, &ShowImageWidget::copyLocation);
+
+    mClipboardMenu->setObjectName(QStringLiteral("mClipboardMenu"));
+    mClipboardMenu->addAction(mClipboardImageAction);
+    mClipboardMenu->addAction(clipboardLocationAction);
+
+    auto clipboardButton = new QToolButton(this);
+    clipboardButton->setObjectName(QStringLiteral("clipboardButton"));
+
+    clipboardButton->setMenu(mClipboardMenu);
+    clipboardButton->setPopupMode(QToolButton::MenuButtonPopup);
+    clipboardButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    buttonBox->addButton(clipboardButton, QDialogButtonBox::ActionRole);
+    clipboardButton->setDefaultAction(clipboardLocationAction);
+
     connect(buttonBox, &QDialogButtonBox::rejected, this, &ShowImageDialog::reject);
     connect(buttonBox->button(QDialogButtonBox::Save), &QPushButton::clicked, mShowImageWidget, &ShowImageWidget::saveAs);
     mainLayout->addWidget(buttonBox);
@@ -58,6 +69,9 @@ ShowImageDialog::~ShowImageDialog()
 void ShowImageDialog::setImageInfo(const ShowImageWidget::ImageInfo &info)
 {
     mShowImageWidget->setImageInfo(info);
+    if (info.isAnimatedImage) {
+        mClipboardImageAction->setEnabled(false);
+    }
 }
 
 void ShowImageDialog::readConfig()
