@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2020 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2020 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "messageattachmentdelegatehelperimage.h"
@@ -63,7 +49,7 @@ void MessageAttachmentDelegateHelperImage::draw(const MessageAttachment &msgAtta
                 } else {
                     mRunningAnimatedImages.emplace_back(index);
                     auto &rai = mRunningAnimatedImages.back();
-                    rai.movie->setFileName(layout.imagePath);
+                    rai.movie->setFileName(layout.imagePreviewPath);
                     rai.movie->setScaledSize(layout.imageSize);
                     auto view = qobject_cast<QAbstractItemView *>(const_cast<QWidget *>(option.widget));
                     const QPersistentModelIndex &idx = rai.index;
@@ -134,17 +120,19 @@ bool MessageAttachmentDelegateHelperImage::handleMouseEvent(const MessageAttachm
             return true;
         } else if (layout.downloadButtonRect.translated(attachmentsRect.topLeft()).contains(pos)) {
             auto *parentWidget = const_cast<QWidget *>(option.widget);
-            DelegateUtil::saveFile(parentWidget, layout.imagePath, i18n("Save Image"));
+            DelegateUtil::saveFile(parentWidget, layout.imagePreviewPath, i18n("Save Image"));
             return true;
         } else if (!layout.pixmap.isNull()) {
             const int imageY = attachmentsRect.y() + layout.titleSize.height() + DelegatePaintUtil::margin();
             const QRect imageRect(attachmentsRect.x(), imageY, layout.imageSize.width(), layout.imageSize.height());
             if (imageRect.contains(pos)) {
                 auto *parentWidget = const_cast<QWidget *>(option.widget);
-                auto dlg = new ShowImageDialog(parentWidget);
+                auto dlg = new ShowImageDialog(Ruqola::self()->rocketChatAccount(), parentWidget);
                 dlg->setAttribute(Qt::WA_DeleteOnClose);
                 ShowImageWidget::ImageInfo info;
-                info.imagePath = layout.imagePath;
+                info.bigImagePath = layout.imageBigPath;
+                info.previewImagePath = layout.imagePreviewPath;
+                info.needToDownloadBigImage = !Ruqola::self()->rocketChatAccount()->attachmentIsInLocalCache(layout.imageBigPath);
                 info.pixmap = layout.pixmap;
                 info.isAnimatedImage = layout.isAnimatedImage;
                 dlg->setImageInfo(info);
@@ -163,16 +151,17 @@ MessageAttachmentDelegateHelperImage::ImageLayout MessageAttachmentDelegateHelpe
                                                                                                     int attachmentsHeight) const
 {
     ImageLayout layout;
-    const QUrl url = Ruqola::self()->rocketChatAccount()->attachmentUrl(msgAttach.link());
+    const QUrl previewImageUrl = Ruqola::self()->rocketChatAccount()->attachmentUrlFromLocalCache(msgAttach.imageUrlPreview());
     layout.title = msgAttach.title();
     layout.description = msgAttach.description();
     layout.titleSize = option.fontMetrics.size(Qt::TextSingleLine, layout.title);
 
     layout.descriptionSize = documentDescriptionForIndexSize(msgAttach, attachmentsWidth);
 
-    if (url.isLocalFile()) {
-        layout.imagePath = url.toLocalFile();
-        layout.pixmap = mPixmapCache.pixmapForLocalFile(layout.imagePath);
+    if (previewImageUrl.isLocalFile()) {
+        layout.imagePreviewPath = previewImageUrl.toLocalFile();
+        layout.imageBigPath = msgAttach.link();
+        layout.pixmap = mPixmapCache.pixmapForLocalFile(layout.imagePreviewPath);
         layout.pixmap.setDevicePixelRatio(option.widget->devicePixelRatioF());
         // or we could do layout.attachment = msgAttach; if we need many fields from it
         layout.isShown = msgAttach.showAttachment();
