@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "messageattachmentdelegatehelpersound.h"
@@ -41,9 +27,7 @@ MessageAttachmentDelegateHelperSound::MessageAttachmentDelegateHelperSound()
 {
 }
 
-MessageAttachmentDelegateHelperSound::~MessageAttachmentDelegateHelperSound()
-{
-}
+MessageAttachmentDelegateHelperSound::~MessageAttachmentDelegateHelperSound() = default;
 
 void MessageAttachmentDelegateHelperSound::draw(const MessageAttachment &msgAttach,
                                                 QPainter *painter,
@@ -110,7 +94,7 @@ MessageAttachmentDelegateHelperSound::SoundLayout
 MessageAttachmentDelegateHelperSound::layoutSound(const MessageAttachment &msgAttach, const QStyleOptionViewItem &option, int attachmentsWidth) const
 {
     SoundLayout layout;
-    const QUrl url = Ruqola::self()->rocketChatAccount()->attachmentUrl(msgAttach.link());
+    const QUrl url = Ruqola::self()->rocketChatAccount()->attachmentUrlFromLocalCache(msgAttach.link());
     // or we could do layout.attachment = msgAttach; if we need many fields from it
     layout.title = msgAttach.title();
     layout.description = msgAttach.description();
