@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2020 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2020 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "messagelistdelegate.h"
@@ -39,6 +25,7 @@
 #include <QAbstractItemView>
 #include <QApplication>
 #include <QDesktopWidget>
+#include <QListView>
 #include <QMouseEvent>
 #include <QPainter>
 #include <QScreen>
@@ -55,8 +42,8 @@ static QSizeF dprAwareSize(const QPixmap &pixmap)
     return pixmap.size() / pixmap.devicePixelRatioF();
 }
 
-MessageListDelegate::MessageListDelegate(QObject *parent)
-    : QItemDelegate(parent)
+MessageListDelegate::MessageListDelegate(QListView *view)
+    : QItemDelegate(view)
     , mEditedIcon(QIcon::fromTheme(QStringLiteral("document-edit")))
     , mRolesIcon(QIcon::fromTheme(QStringLiteral("documentinfo")))
     // https://bugs.kde.org/show_bug.cgi?id=417298 added smiley-add to KF 5.68
@@ -64,7 +51,8 @@ MessageListDelegate::MessageListDelegate(QObject *parent)
     , mFavoriteIcon(QIcon::fromTheme(QStringLiteral("favorite")))
     , mPinIcon(QIcon::fromTheme(QStringLiteral("pin")))
     , mTranslatedIcon(QIcon::fromTheme(QStringLiteral("languages"))) // TODO use another icon for it. But kde doesn't correct icon perhaps flags ?
-    , mHelperText(new MessageDelegateHelperText)
+    , mListView(view)
+    , mHelperText(new MessageDelegateHelperText(view))
     , mHelperAttachmentImage(new MessageAttachmentDelegateHelperImage)
     , mHelperAttachmentFile(new MessageAttachmentDelegateHelperFile)
     , mHelperReactions(new MessageDelegateHelperReactions)
@@ -79,9 +67,7 @@ MessageListDelegate::MessageListDelegate(QObject *parent)
     mReplyThreadColorMode = scheme.foreground(KColorScheme::NegativeText).color();
 }
 
-MessageListDelegate::~MessageListDelegate()
-{
-}
+MessageListDelegate::~MessageListDelegate() = default;
 
 void MessageListDelegate::setRocketChatAccount(RocketChatAccount *rcAccount)
 {
@@ -104,7 +90,7 @@ static QSize timeStampSize(const QString &timeStampText, const QStyleOptionViewI
 QPixmap MessageListDelegate::makeAvatarPixmap(const QWidget *widget, const QModelIndex &index, int maxHeight) const
 {
     const QString emojiStr = index.data(MessageModel::Emoji).toString();
-    const Utils::AvatarInfo info = index.data(MessageModel::AvatarInfo).value<Utils::AvatarInfo>();
+    const auto info = index.data(MessageModel::AvatarInfo).value<Utils::AvatarInfo>();
     if (emojiStr.isEmpty()) {
         const QString avatarUrl = index.data(MessageModel::Avatar).toString();
         if (!avatarUrl.isEmpty()) {
@@ -345,7 +331,7 @@ void MessageListDelegate::drawDate(QPainter *painter, const QModelIndex &index,
 void MessageListDelegate::selectAll(const QStyleOptionViewItem &option, const QModelIndex &index)
 {
     const Layout layout = doLayout(option, index);
-    mHelperText->selectAll(option.widget, layout.textRect, index);
+    mHelperText->selectAll(index);
 }
 
 void MessageListDelegate::clearTextDocumentCache()
@@ -353,6 +339,11 @@ void MessageListDelegate::clearTextDocumentCache()
     mHelperText->clearTextDocumentCache();
 }
 
+void MessageListDelegate::clearSelection()
+{
+    mHelperText->clearSelection();
+}
+
 QString MessageListDelegate::selectedText() const
 {
     return mHelperText->selectedText();
@@ -532,11 +523,10 @@ bool MessageListDelegate::mouseEvent(QEvent *event, const QStyleOptionViewItem &
         const Message::MessageType messageType = message->messageType();
         const bool isSystemMessage = (messageType == Message::System) || (messageType == Message::Information);
         if (layout.addReactionRect.contains(mev->pos()) && !isSystemMessage) {
-            auto *parentWidget = const_cast<QWidget *>(option.widget);
-            auto mEmoticonMenuWidget = new EmoticonMenuWidget(parentWidget);
+            auto mEmoticonMenuWidget = new EmoticonMenuWidget(mListView);
             mEmoticonMenuWidget->setWindowFlag(Qt::Popup);
             mEmoticonMenuWidget->setCurrentRocketChatAccount(mRocketChatAccount);
-            positionPopup(mev->globalPos(), parentWidget, mEmoticonMenuWidget);
+            positionPopup(mev->globalPos(), mListView, mEmoticonMenuWidget);
             mEmoticonMenuWidget->show();
             connect(mEmoticonMenuWidget, &EmoticonMenuWidget::insertEmoticons, this, [=](const QString &id) {
                 mRocketChatAccount->reactOnMessage(message->messageId(), id, true /*add*/);
@@ -659,7 +649,7 @@ bool MessageListDelegate::helpEvent(QHelpEvent *helpEvent, QAbstractItemView *vi
             QToolTip::showText(helpEvent->globalPos(), tooltip, view);
             return true;
         }
-        if (layout.textRect.contains(helpEvent->pos()) && mHelperText->handleHelpEvent(helpEvent, view, layout.textRect, index)) {
+        if (layout.textRect.contains(helpEvent->pos()) && mHelperText->handleHelpEvent(helpEvent, layout.textRect, index)) {
             return true;
         }
         if (layout.timeStampRect.contains(helpEvent->pos())) {
