@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "roomwidget.h"
@@ -139,7 +125,7 @@ void RoomWidget::slotChannelInfoRequested()
         return;
     }
     if (mRoomType == Room::RoomType::Direct) {
-        QPointer<DirectChannelInfoDialog> dlg = new DirectChannelInfoDialog(this);
+        QPointer<DirectChannelInfoDialog> dlg = new DirectChannelInfoDialog(mCurrentRocketChatAccount, this);
         dlg->setUserName(mRoom->name());
         dlg->exec();
         delete dlg;
@@ -209,6 +195,12 @@ void RoomWidget::slotActionRequested(RoomHeaderWidget::ChannelActionType type)
     case RoomHeaderWidget::FollowMessages:
         slotFollowMessages();
         break;
+    case RoomHeaderWidget::OtrMessages:
+        // TODO
+        break;
+    case RoomHeaderWidget::EncryptMessages:
+        // TODO
+        break;
     }
 }
 
@@ -264,11 +256,10 @@ void RoomWidget::slotAddUsersInRoom()
 
 void RoomWidget::slotInviteUsers()
 {
-    QPointer<InviteUsersDialog> dlg = new InviteUsersDialog(mCurrentRocketChatAccount, this);
-    dlg->setRoomId(mRoomWidgetBase->roomId());
-    dlg->generateLink();
-    dlg->exec();
-    delete dlg;
+    InviteUsersDialog dlg(mCurrentRocketChatAccount, this);
+    dlg.setRoomId(mRoomWidgetBase->roomId());
+    dlg.generateLink();
+    dlg.exec();
 }
 
 void RoomWidget::updateListView()
@@ -281,10 +272,9 @@ void RoomWidget::slotConfigureAutoTranslate()
     if (!mRoom) {
         return;
     }
-    QPointer<AutoTranslateConfigureDialog> dlg = new AutoTranslateConfigureDialog(this);
-    dlg->setRoom(mRoom);
-    dlg->exec();
-    delete dlg;
+    AutoTranslateConfigureDialog dlg(mCurrentRocketChatAccount, this);
+    dlg.setRoom(mRoom);
+    dlg.exec();
 }
 
 void RoomWidget::slotConfigureNotification()
@@ -292,10 +282,9 @@ void RoomWidget::slotConfigureNotification()
     if (!mRoom) {
         return;
     }
-    QPointer<ConfigureNotificationDialog> dlg = new ConfigureNotificationDialog(mCurrentRocketChatAccount, this);
-    dlg->setRoom(mRoom);
-    dlg->exec();
-    delete dlg;
+    ConfigureNotificationDialog dlg(mCurrentRocketChatAccount, this);
+    dlg.setRoom(mRoom);
+    dlg.exec();
 }
 
 void RoomWidget::slotStarredMessages()
@@ -303,7 +292,7 @@ void RoomWidget::slotStarredMessages()
     if (!mRoom) {
         return;
     }
-    QPointer<ShowStarredMessagesDialog> dlg = new ShowStarredMessagesDialog(this);
+    QPointer<ShowStarredMessagesDialog> dlg = new ShowStarredMessagesDialog(mCurrentRocketChatAccount, this);
     dlg->setRoomId(mRoomWidgetBase->roomId());
     dlg->setModel(mCurrentRocketChatAccount->listMessagesFilterProxyModel());
     dlg->setCurrentRocketChatAccount(mCurrentRocketChatAccount);
@@ -319,7 +308,7 @@ void RoomWidget::slotPinnedMessages()
     if (!mRoom) {
         return;
     }
-    QPointer<ShowPinnedMessagesDialog> dlg = new ShowPinnedMessagesDialog(this);
+    QPointer<ShowPinnedMessagesDialog> dlg = new ShowPinnedMessagesDialog(mCurrentRocketChatAccount, this);
     dlg->setRoomId(mRoomWidgetBase->roomId());
     dlg->setCurrentRocketChatAccount(mCurrentRocketChatAccount);
     dlg->setRoom(mRoom);
@@ -335,7 +324,7 @@ void RoomWidget::slotShowMentions()
     if (!mRoom) {
         return;
     }
-    QPointer<ShowMentionsMessagesDialog> dlg = new ShowMentionsMessagesDialog(this);
+    QPointer<ShowMentionsMessagesDialog> dlg = new ShowMentionsMessagesDialog(mCurrentRocketChatAccount, this);
     dlg->setRoomId(mRoomWidgetBase->roomId());
     dlg->setModel(mCurrentRocketChatAccount->listMessagesFilterProxyModel());
     dlg->setCurrentRocketChatAccount(mCurrentRocketChatAccount);
@@ -351,7 +340,7 @@ void RoomWidget::slotSnipperedMessages()
     if (!mRoom) {
         return;
     }
-    QPointer<ShowSnipperedMessagesDialog> dlg = new ShowSnipperedMessagesDialog(this);
+    QPointer<ShowSnipperedMessagesDialog> dlg = new ShowSnipperedMessagesDialog(mCurrentRocketChatAccount, this);
     dlg->setRoomId(mRoomWidgetBase->roomId());
     dlg->setModel(mCurrentRocketChatAccount->listMessagesFilterProxyModel());
     dlg->setCurrentRocketChatAccount(mCurrentRocketChatAccount);
@@ -367,7 +356,7 @@ void RoomWidget::slotShowThreads()
     if (!mRoom) {
         return;
     }
-    QPointer<ShowThreadsDialog> dlg = new ShowThreadsDialog(this);
+    QPointer<ShowThreadsDialog> dlg = new ShowThreadsDialog(mCurrentRocketChatAccount, this);
     dlg->setCurrentRocketChatAccount(mCurrentRocketChatAccount);
     dlg->setModel(mCurrentRocketChatAccount->listMessagesFilterProxyModel());
     dlg->setRoomId(mRoomWidgetBase->roomId());
@@ -424,10 +413,9 @@ void RoomWidget::slotTeamChannelsRequested()
     if (!mRoom) {
         return;
     }
-    QPointer<TeamChannelsDialog> dlg = new TeamChannelsDialog(mCurrentRocketChatAccount, this);
-    dlg->setRoom(mRoom);
-    dlg->exec();
-    delete dlg;
+    TeamChannelsDialog dlg(mCurrentRocketChatAccount, this);
+    dlg.setRoom(mRoom);
+    dlg.exec();
 }
 
 void RoomWidget::slotCreateNewDiscussion(const QString &messageId, const QString &originalMessage)
@@ -757,13 +745,11 @@ void RoomWidget::slotGoBackToRoom()
 
 void RoomWidget::slotOpenThreadRequested(const QString &threadMessageId, const QString &threadMessagePreview)
 {
-    QPointer<ThreadMessageDialog> dlg = new ThreadMessageDialog(this);
-    dlg->setThreadMessageId(threadMessageId);
-    dlg->setCurrentRocketChatAccount(mCurrentRocketChatAccount);
-    dlg->setThreadPreview(threadMessagePreview);
-    dlg->setRoom(mRoom);
-    dlg->exec();
-    delete dlg;
+    ThreadMessageDialog dlg(mCurrentRocketChatAccount, this);
+    dlg.setThreadMessageId(threadMessageId);
+    dlg.setThreadPreview(threadMessagePreview);
+    dlg.setRoom(mRoom);
+    dlg.exec();
 }
 
 void RoomWidget::slotFollowMessages()
